Package: prettyR
Version: 2.2-3
Title: Pretty Descriptive Stats
Date: 2019-04-08
Author: Jim Lemon <drjimlemon@gmail.com>,
 Philippe Grosjean <phgrosjean@sciviews.org>
Maintainer: Jim Lemon <drjimlemon@gmail.com>
Description: Functions for conventionally formatting descriptive stats,
 reshaping data frames and formatting R output as HTML.
Imports: grDevices, stats, utils
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2019-04-08 03:30:00 UTC; root
Repository: CRAN
Date/Publication: 2019-04-09 05:10:03 UTC
