# created 6/9/2011 - Jim Lemon,
 importFrom("grDevices", "bmp", "graphics.off", "jpeg", "png")
 importFrom("stats", "as.formula", "chisq.test", "terms")
 importFrom("utils", "browseURL")
export(
 add.value.labels,
 AddNav,
 AddNavItem,
 addxtabs,
 BeginNav,
 brkdn,
 calculate.xtab,
 CreateIndexFile,
 createIndxFile,
 decimal.align,
 delim.table,
 delim.xtab,
 describe,
 describe.factor,
 describe.logical,
 describe.numeric,
 EndHTML,
 freq,
 HTMLgraph,
 htmlize,
 Mode,
 R2html,
 rep_n_stack,
 skew,
 StartList,
 StartNav,
 stretch_df,
 toNA,
 truncString,
 valid.n,
 xtab
)
# methods
S3method(print,freq)
S3method(print,xtab)
S3method(print,desc)
